@@ -10,8 +10,8 @@ from distutils.util import strtobool
 from typing import Optional, Any, Dict
 from yarl import URL
 from tenacity import retry, stop_after_attempt, wait_fixed, retry_if_exception_type, before_log
-from .const import (COMMAND_GET_STATUS, COMMAND_GET_MODEL_DESC, ENDPOINT_AI, VERSION, DEVICE_TYPE_UNKNOWN,
-                    DEVICE_TYPE_WASHING_MACHINE, DEVICE_TYPE_DRYER, MODEL_MATCH_WASHING_MACHINE, MODEL_MATCH_DRYER,
+from .const import (QUERY_PARAM_COMMAND, QUERY_PARAM_VALUE, COMMAND_GET_STATUS, COMMAND_GET_MODEL_DESC,
+                    COMMAND_GET_MACHINE_TYPE, ENDPOINT_AI, VERSION, DEVICE_TYPE_UNKNOWN, DEVICE_TYPE_MAPPING,
                     ENDPOINT_HH, COMMAND_GET_COMMAND)
 from .digest_auth import DigestAuth
 
@@ -87,7 +87,8 @@ class BasicDevice:
         self._uuid = ""
         self._active = False
         self._device_information_loaded = False
-        self._device_type = DEVICE_TYPE_UNKNOWN
+        self._device_type_short = ""
+        self._device_type: Optional[str] = DEVICE_TYPE_UNKNOWN
         self._logger = logging.getLogger(__name__)
         self._auth_previous: Dict[str, str] = {}
 
@@ -95,7 +96,7 @@ class BasicDevice:
         return URL.build(scheme='http', host=self._host.replace("http://", ""))
 
     def get_command_url(self, endpoint: str, command: str) -> URL:
-        return self.get_base_url().join(URL(endpoint)).update_query({'command': command})
+        return self.get_base_url().join(URL(endpoint)).update_query({QUERY_PARAM_COMMAND: command})
 
     async def make_vzug_device_call_raw(self, url: URL) -> str:
         """
@@ -109,9 +110,9 @@ class BasicDevice:
                 auth = DigestAuth(self._username, self._password, session, self._auth_previous)
                 resp = await auth.request('GET', url=url, headers=REQUEST_HEADERS)
                 self._auth_previous = {
-                  'nonce_count': auth.nonce_count,
-                  'last_nonce': auth.last_nonce,
-                  'challenge': auth.challenge,
+                    'nonce_count': auth.nonce_count,
+                    'last_nonce': auth.last_nonce,
+                    'challenge': auth.challenge,
                 }
 
                 if aiohttp.web.HTTPUnauthorized.status_code == resp.status:
@@ -183,7 +184,11 @@ class BasicDevice:
             self._model_desc = await self.make_vzug_device_call_raw(
                 self.get_command_url(ENDPOINT_AI, COMMAND_GET_MODEL_DESC))
 
-            self._set_device_type(self._model_desc)
+            # Load short device type in separate call
+            self._device_type_short = await self.make_vzug_device_call_raw(
+                self.get_command_url(ENDPOINT_HH, COMMAND_GET_MACHINE_TYPE))
+
+            self._set_device_type()
             self._device_information_loaded = True
 
             self._logger.info("Got device information. Type: %s, model: %s, serial: %s, uuid: %s, name: %s, status: %s",
@@ -196,17 +201,15 @@ class BasicDevice:
             self._error_exception = e
             return False
 
-    def _set_device_type(self, device_model: str) -> None:
-        if MODEL_MATCH_WASHING_MACHINE in device_model.lower():
-            self._device_type = DEVICE_TYPE_WASHING_MACHINE
-        elif MODEL_MATCH_DRYER in device_model.lower():
-            self._device_type = DEVICE_TYPE_DRYER
+    def _set_device_type(self) -> None:
+        if self._device_type_short in DEVICE_TYPE_MAPPING:
+            self._device_type = DEVICE_TYPE_MAPPING.get(self._device_type_short)
         else:
             self._device_type = DEVICE_TYPE_UNKNOWN
 
     async def do_consumption_details_request(self, command: str) -> str:
 
-        url = self.get_command_url(ENDPOINT_HH, COMMAND_GET_COMMAND).update_query({'value': command})
+        url = self.get_command_url(ENDPOINT_HH, COMMAND_GET_COMMAND).update_query({QUERY_PARAM_VALUE: command})
         eco_json = await self.make_vzug_device_call_json(url)
 
         if CONSUMPTION_DETAILS_VALUE in eco_json:
@@ -260,7 +263,7 @@ class BasicDevice:
         return self._device_information_loaded
 
     @property
-    def device_type(self) -> str:
+    def device_type(self) -> Optional[str]:
         return self._device_type
 
     @property
